This is the github repository for my bachelor thesis.<br>
<br>
pip install . <br>
works for windows11 and ubuntu 22 <br>
upgrade pip before installation, as pyproject.toml without setup.cfg is a rather new standard <br>
